@@ -1,5 +1,6 @@
 import sys
-if (sys.version_info > (3, 0)):
+
+if sys.version_info > (3, 0):
     from . import notation
     from . import tensors
     from . import utils
@@ -12,4 +13,8 @@ else:
     import utils
     import material
     import fabric_tensors
-    import visualization
\ No newline at end of file
+    import visualization
+
+import pkg_resources
+
+__version__ = pkg_resources.get_distribution("pip").version
